@@ -1,5 +1,5 @@
 package Pod::AsciiDoctor;
-$Pod::AsciiDoctor::VERSION = '0.102000';
+$Pod::AsciiDoctor::VERSION = '0.102001';
 use 5.014;
 use strict;
 use warnings FATAL => 'all';
@@ -179,12 +179,17 @@ sub make_header
 sub make_text
 {
     my ( $self, $paragraph, $list ) = @_;
+
     my @lines = split "\n", $paragraph;
     my $data  = $self->_prop;
     my @i_paragraph;
     my $pnt = $list ? "*" : "";
     for my $line (@lines)
     {
+        if ($list)
+        {
+            $line =~ s/\A\*\s*//ms;
+        }
         push @i_paragraph, $pnt x $data->{indent} . " " . $line . "\n";
     }
     return join "\n", @i_paragraph;
@@ -218,7 +223,7 @@ Pod::AsciiDoctor - Convert from POD to AsciiDoc
 
 =head1 VERSION
 
-version 0.102000
+version 0.102001
 
 =head1 SYNOPSIS
 
